window.Gleam.initSearch([{"doc":"staff_ai","title":"staff_ai","content":"# staff\n\n[![Package Version](https://img.shields.io/hexpm/v/staff_ai)](https://hex.pm/packages/staff_ai)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/staff_ai/)\n\n```sh\ngleam add staff_ai\n```\n```gleam\nimport staff_ai/agent.{create}\n\npub fn main() {\n  let agent =\n    create(\n      &quot;John Doe&quot;,\n      &quot;AI researcher&quot;,\n      Some(\n        &quot;John is an AI researcher who is passionate about building AI agents\n        that can accomplish tasks for people. He has a PhD in AI and has been\n        working in the field for over 10 years.\n        He is excited to be a part of the Staff-AI team.&quot;,\n      ),\n    )\n  io.debug(agent)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/staff_ai&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"staff_ai/agent","title":"Agent","content":"pub type Agent {\n  Agent(\n    id: UUID,\n    name: String,\n    role: String,\n    context: Option(String),\n  )\n}\n Represents an AI worker in a staff system\n \nAgent(\n  id: UUID,\n  name: String,\n  role: String,\n  context: Option(String),\n)\n\nid\n&lt;p&gt;Unique identifier of the agent&lt;/p&gt;\n\nname\n&lt;p&gt;Name of the agent, which is used to identify him in your system.\nIt can be a real name or a nickname, e.g. “Jane Doe” or “jane_doe”&lt;/p&gt;\n\nrole\n&lt;p&gt;Role of the agent, which is used to identify his skills and responsibilities in your system.\nIt can be a real role or a nickname, e.g. “Software Developer” or “dev”&lt;/p&gt;\n\ncontext\n&lt;p&gt;Adding a context to an agent is optional, but it can be useful to store additional information about the agent.\nIt can be used to store additional information about the agent as it will influence the way it reacts to tasks.\nE.g. “Jane Doe is a technical lead of the project X. She is responsible for the architecture and …”&lt;/p&gt;\n\nSynonyms:\nstaff_ai/agent.Agent\nstaff_ai/agent Agent","url":"staff_ai/agent.html#Agent"},{"doc":"staff_ai/agent","title":"UUID","content":"pub type UUID =\n  String\n Represents a unique identifier of an agent, which is a string in the UUID format.\n \n\nSynonyms:\nstaff_ai/agent.UUID\nstaff_ai/agent UUID","url":"staff_ai/agent.html#UUID"},{"doc":"staff_ai/agent","title":"create","content":"pub fn create(\n  name: String,\n  role: String,\n  context: Option(String),\n) -&gt; Agent\n Creates a new agent with the given parameters.\n \nSynonyms:\nstaff_ai/agent.create\nstaff_ai/agent create","url":"staff_ai/agent.html#create"},{"doc":"staff_ai/agent","title":"staff_ai/agent","content":"","url":"staff_ai/agent.html"},{"doc":"staff_ai/task","title":"Task","content":"pub type Task {\n  Task(\n    id: UUID,\n    title: String,\n    description: String,\n    status: TaskStatus,\n    assigned_agent: Option(UUID),\n    created_at: Time,\n    updated_at: Time,\n    completed_at: Option(Time),\n    cancelled_at: Option(Time),\n    failed_at: Option(Time),\n  )\n}\n A task that can be performed by an agent\n \nTask(\n  id: UUID,\n  title: String,\n  description: String,\n  status: TaskStatus,\n  assigned_agent: Option(UUID),\n  created_at: Time,\n  updated_at: Time,\n  completed_at: Option(Time),\n  cancelled_at: Option(Time),\n  failed_at: Option(Time),\n)\n\nid\n&lt;p&gt;The unique identifier of the task&lt;/p&gt;\n\ntitle\n&lt;p&gt;A meaningful title of the task&lt;/p&gt;\n\ndescription\n&lt;p&gt;A description of the task, must be detailed enough to be performed&lt;/p&gt;\n\nstatus\n&lt;p&gt;The status of the task&lt;/p&gt;\n\nassigned_agent\n&lt;p&gt;The unique identifier of the agent that has been assigned to perform the task&lt;/p&gt;\n\ncreated_at\n&lt;p&gt;The time when the task was created&lt;/p&gt;\n\nupdated_at\n&lt;p&gt;The time when the task was last updated&lt;/p&gt;\n\ncompleted_at\n&lt;p&gt;The time when the task was completed&lt;/p&gt;\n\ncancelled_at\n&lt;p&gt;The time when the task was cancelled&lt;/p&gt;\n\nfailed_at\n&lt;p&gt;The time when the task has failed&lt;/p&gt;\n\nSynonyms:\nstaff_ai/task.Task\nstaff_ai/task Task","url":"staff_ai/task.html#Task"},{"doc":"staff_ai/task","title":"TaskStatus","content":"pub type TaskStatus {\n  Ready\n  InProgress\n  Completed\n  Cancelled\n  Failed\n}\n The status of the task\n \nReady\n The task is ready to be performed\n\nInProgress\n The task is currently being performed\n\nCompleted\n The task has been completed\n\nCancelled\n The task has been cancelled\n\nFailed\n The task has failed\n\nSynonyms:\nstaff_ai/task.TaskStatus\nstaff_ai/task TaskStatus","url":"staff_ai/task.html#TaskStatus"},{"doc":"staff_ai/task","title":"UUID","content":"pub type UUID =\n  String\n Represents a unique identifier of a task, which is a string in the UUID format.\n \n\nSynonyms:\nstaff_ai/task.UUID\nstaff_ai/task UUID","url":"staff_ai/task.html#UUID"},{"doc":"staff_ai/task","title":"create","content":"pub fn create(\n  title: String,\n  description: String,\n  assigned_agent: Option(String),\n) -&gt; Task\n The unique identifier of the task\n A meaningful title of the task\n A description of the task, must be detailed enough to be performed\n The status of the task\n The unique identifier of the agent that has been assigned to perform the task\n The time when the task was created\n The time when the task was last updated\n The time when the task was completed\n The time when the task was cancelled\n The time when the task has failed\n\nSynonyms:\nstaff_ai/task.create\nstaff_ai/task create","url":"staff_ai/task.html#create"},{"doc":"staff_ai/task","title":"staff_ai/task","content":"","url":"staff_ai/task.html"},{"doc":"staff_ai","title":"main","content":"pub fn main() -&gt; Task\n\nSynonyms:\nstaff_ai.main\nstaff_ai main","url":"staff_ai.html#main"},{"doc":"staff_ai","title":"staff_ai","content":"","url":"staff_ai.html"}]);